import { Renderer } from '@angular/core';
import 'prismjs/components/prism-bash';
import 'prismjs/components/prism-powershell';
import 'prismjs/components/prism-javascript';
import 'prismjs/plugins/line-numbers/prism-line-numbers';
import 'prismjs/plugins/command-line/prism-command-line';
import 'prismjs/plugins/normalize-whitespace/prism-normalize-whitespace';
/**
 * Code highlighting component
 *
 * Used internally by a codeblock to perform the actual highlighting.
 */
export declare class CodeRendererComponent {
    private _renderer;
    /**
     * The code to highlight
     */
    code: string;
    /**
     * The language to use when highlighting the code.
     */
    language: string;
    /**
     * Whether or not to display line numbers.
     */
    lineNumbers: boolean;
    /**
     * Display a prompt in the codeblock. Set to 'bash' or 'powershell'.
     */
    shell: string;
    /**
     * The prompt to use when displaying as a shell.
     */
    prompt: string;
    /**
     * A comma separated list of lines or groups of lines to treat as output
     * in a shell display.
     */
    outputLines: string;
    /**
     * The template <pre> that will contain the code.
     */
    _pre: any;
    constructor(_renderer: Renderer);
    render(): void;
    /**
     * Clear the code.
     */
    empty(): void;
    /**
     * Place the new code element in the template
     */
    _replaceCode(): void;
    /**
     * Perform the actual highlighting
     */
    _highlight(): void;
    /**
     * Code prepared for highlighting and display
     */
    readonly _processedCode: string;
    /**
     * Format markup for display.
     */
    _processMarkup(text: string): string;
    /**
     * Change all opening < changed to &lt; to render markup correctly inside pre
     * tags
     */
    _replaceTags(text: string): string;
    /**
     * Remove both template tags and styling attributes added by the angular2
     * parser and fix indentation within code elements created by structural
     * directives.
     */
    _removeAngularMarkup(html: string): string;
    /**
     * Is the language given a markup language?
     */
    _isMarkup(language: string): boolean;
    /**
     * Create a <code> element with the proper classes and formatted code
     */
    _buildCodeElement(): string;
    /** Styling classes **/
    readonly languageClass: string;
    readonly lineNumbersClass: string;
    readonly shellClass: string;
    readonly codeClasses: string;
    readonly preClasses: string;
    /** Code Styling **/
    /**
     * The code element within <pre>
     */
    readonly _codeEl: any;
    /**
     * Adds back padding on output shells because of floated left prompt
     */
    _fixPromptOutputPadding(): void;
    /**
     * Get the actually applied style of an element
     */
    _getStyle(oElm: any, strCssRule: string): string;
    /**
     * Remove extra indentation in ngSwitches
     */
    _fixIndentation(html: string): Array<string>;
}
